==> ejc-sddjsorg-impl-3.0.0-20211020.020248-35-sources.jar: com/ejianc/business/sddjsorg/controller/OrgApplyFileSetController.java <==
package com.ejianc.business.sddjsorg.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.sddjsorg.bean.OrgApplyFileSetEntity;
import com.ejianc.business.sddjsorg.service.IOrgApplyFileSetService;
import com.ejianc.business.sddjsorg.vo.OrgApplyFileSetVO;

/**
 * 组织机构申请-资料设置
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("orgApplyFileSet")
public class OrgApplyFileSetController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private IOrgApplyFileSetService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OrgApplyFileSetVO> saveOrUpdate(@RequestBody OrgApplyFileSetVO saveorUpdateVO) {
    	OrgApplyFileSetEntity entity = BeanMapper.map(saveorUpdateVO, OrgApplyFileSetEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
        }
    	service.saveOrUpdate(entity, false);
    	OrgApplyFileSetVO vo = BeanMapper.map(entity, OrgApplyFileSetVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OrgApplyFileSetVO> queryDetail(Long id) {
    	OrgApplyFileSetEntity entity = service.selectById(id);
    	OrgApplyFileSetVO vo = BeanMapper.map(entity, OrgApplyFileSetVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OrgApplyFileSetVO> vos) {
        service.removeByIds(vos.stream().map(OrgApplyFileSetVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OrgApplyFileSetVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<OrgApplyFileSetEntity> page = service.queryPage(param,false);
        IPage<OrgApplyFileSetVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), OrgApplyFileSetVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description queryList 根据申请单类型 查询档案设置详情
     * @param applyTypeCode
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryFileSetInfoList", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<OrgApplyFileSetVO>> queryFileSetInfoList(@RequestParam("applyTypeCode") String applyTypeCode) {
        QueryParam param = new QueryParam();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("type", new Parameter(QueryParam.EQ, applyTypeCode));
        param.getParams().put("inUse", new Parameter(QueryParam.EQ, true));

        List<OrgApplyFileSetEntity> page = service.queryList(param,false);
        List<OrgApplyFileSetVO> pageData = BeanMapper.mapList(page, OrgApplyFileSetVO.class);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<OrgApplyFileSetEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("OrgApplyFileSet-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refOrgApplyFileSetData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<OrgApplyFileSetVO>> refOrgApplyFileSetData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<OrgApplyFileSetEntity> page = service.queryPage(param,false);
        IPage<OrgApplyFileSetVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), OrgApplyFileSetVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-sddjsorg-impl-3.0.0-20211026.113402-93-sources.jar: com/ejianc/business/sddjsorg/controller/OrgApplyFileSetController.java <==
package com.ejianc.business.sddjsorg.controller;

import java.io.Serializable;

import com.ejianc.business.sddjsorg.bean.OrgApplyFileEntity;
import com.ejianc.business.sddjsorg.bean.ShareholderDecisionFileEntity;
import com.ejianc.business.sddjsorg.service.*;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.util.ExcelExport;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.util.Strings;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.sddjsorg.bean.OrgApplyFileSetEntity;
import com.ejianc.business.sddjsorg.vo.OrgApplyFileSetVO;

/**
 * 组织机构申请-资料设置
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("orgApplyFileSet")
public class OrgApplyFileSetController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private IShareholderDecisionFileService shareholderDecisionFileService;

    @Autowired
    private IOrgApplyFileService orgApplyFileService;

    @Autowired
    private IOrgApplyFileSetService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OrgApplyFileSetVO> saveOrUpdate(@RequestBody OrgApplyFileSetVO saveorUpdateVO) {
    	OrgApplyFileSetEntity entity = BeanMapper.map(saveorUpdateVO, OrgApplyFileSetEntity.class);
    	service.saveOrUpdate(entity, false);
    	OrgApplyFileSetVO vo = BeanMapper.map(entity, OrgApplyFileSetVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OrgApplyFileSetVO> queryDetail(Long id) {
    	OrgApplyFileSetEntity entity = service.selectById(id);
    	OrgApplyFileSetVO vo = BeanMapper.map(entity, OrgApplyFileSetVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OrgApplyFileSetVO> vos) {
        QueryParam param = new QueryParam();
        param.getParams().put("fileSetId",new Parameter(QueryParam.IN,vos.stream().map(OrgApplyFileSetVO::getId).collect(Collectors.toList())));
        if(vos.get(0).getType().equals("decision")){//股东决策
            List<ShareholderDecisionFileEntity> exist = shareholderDecisionFileService.queryList(param);
            if(ListUtil.isNotEmpty(exist)){
                return CommonResponse.error("删除失败！数据已被引用不允许删除："+ Strings.join(Lists.newArrayList(exist.stream().map(ShareholderDecisionFileEntity::getFileSetName).distinct().collect(Collectors.toList())), ','));
            }
        }else {
            List<OrgApplyFileEntity> exist = orgApplyFileService.queryList(param);
            if(ListUtil.isNotEmpty(exist)){
                return CommonResponse.error("删除失败！数据已被引用不允许删除："+ Strings.join(Lists.newArrayList(exist.stream().map(OrgApplyFileEntity::getName).distinct().collect(Collectors.toList())), ','));
            }
        }
        service.removeByIds(vos.stream().map(OrgApplyFileSetVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OrgApplyFileSetVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<OrgApplyFileSetEntity> page = service.queryPage(param,false);
        IPage<OrgApplyFileSetVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), OrgApplyFileSetVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description queryList 根据申请单类型 查询档案设置列表
     * @param applyTypeCode
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryFileSetInfoList", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<OrgApplyFileSetVO>> queryFileSetInfoList(@RequestParam("applyTypeCode") String applyTypeCode) {
        QueryParam param = new QueryParam();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("type", new Parameter(QueryParam.EQ, applyTypeCode));
        param.getParams().put("inUse", new Parameter(QueryParam.EQ, true));

        List<OrgApplyFileSetEntity> page = service.queryList(param,false);
        List<OrgApplyFileSetVO> pageData = BeanMapper.mapList(page, OrgApplyFileSetVO.class);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        List<OrgApplyFileSetEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("OrgApplyFileSet-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refOrgApplyFileSetData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<OrgApplyFileSetVO>> refOrgApplyFileSetData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<OrgApplyFileSetEntity> page = service.queryPage(param,false);
        IPage<OrgApplyFileSetVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), OrgApplyFileSetVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
